powered by
The function applies a Savitkzy-Golay smoothing filter on the spectra file based on settings defined by the user.
savit.gol(x, filt, filt_order = 4, der_order = 0)
A vector with the intensity values that should be smoothed.
Numeric.The length of the filter length, must be odd.
Numeric. Filter order: 2 = quadratic filter, 4 = quartic. Default is 4.
Numeric. Derivative order: 0 = smoothing, 1 = first derivative, etc. Default is 0.
Return the spectra with the removed region. The rows corresponding to the range specified are removed.
# NOT RUN { data("MPdatabase") smooth.vect<-savit.gol(MPdatabase[,6], filt=11) # }
Run the code above in your browser using DataLab